@@ -73,8 +73,7 @@ gst_auto_audio_sink_base_init (gpointer klass)
 {
   GstElementClass *eklass = GST_ELEMENT_CLASS (klass);
 
-  gst_element_class_add_pad_template (eklass,
-      gst_static_pad_template_get (&sink_template));
+  gst_element_class_add_static_pad_template (eklass, &sink_template);
 
   gst_element_class_set_details_simple (eklass, "Auto audio sink",
       "Sink/Audio",
